@@ -3,18 +3,27 @@
 """\
 A simple but flexible parser of SUSY Les Houches Accord (SLHA) model and decay files.
 
-TODO: What to do about unlisted PIDs?
-TODO: Split writeSLHA into writeSLHA{Blocks,Decays}
-TODO: Handle SLHA2
-TODO: Handle RPV SUSY in ISAWIG
-TODO: Identify HERWIG decay matrix element to use in ISAWIG
-TODO: Order decay products as required by HERWIG in ISAWIG
+pyslha is a parser/writer module for particle physics SUSY Les Houches Accord
+(SLHA) supersymmetric spectrum/decay files, and a collection of scripts which
+use the interface, e.g. for conversion to and from the legacy ISAWIG format, or
+to plot the mass spectrum and decay chains.
+
+The current release supports SLHA version 1. Assistance with supporting version
+2 will be gladly accepted!
+
+TODOs:
+ * What to do about unlisted PIDs?
+ * Split writeSLHA into writeSLHA{Blocks,Decays}
+ * Handle SLHA2
+ * Handle RPV SUSY in ISAWIG
+ * Identify HERWIG decay matrix element to use in ISAWIG
+ * Order decay products as required by HERWIG in ISAWIG
 """
 
 from __future__ import with_statement
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 
 def _autotype(var):
